<?php

namespace IPS\filespurchased\extensions\core\Profile;

/* To prevent PHP errors (extending class does not exist) revealing path */
if ( !\defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

class _filesPurchased
{
	protected $member;

	public function __construct( \IPS\Member $member )
	{
		$this->member = $member;
	}

	public function showTab(): bool
	{
		if( \IPS\Member::loggedIn()->isAdmin() )
		{
			return TRUE;
		}

		return FALSE;
	}

	public function render(): string
	{
		$files = array();
		foreach( new \IPS\Patterns\ActiveRecordIterator( \IPS\Db::i()->select( '*', 'nexus_purchases', array( 'ps_member=? AND ps_app=? AND ps_type=?', $this->member->member_id, 'downloads', 'file' ) ), 'IPS\nexus\Purchase' ) as $purchase )
		{
			$files[ $purchase->item_id ] = $purchase->item_id;
		}

		if( \count( $files ) )
		{
			$total = \IPS\downloads\File::getItemsWithPermission( array( 'file_id IN(' . implode( ',', $files ) . ')' ), NULL, 1, 'read', NULL, 0, NULL, FALSE, FALSE, FALSE, TRUE );
			$table = new \IPS\Helpers\Table\Content( 'IPS\downloads\File', $this->member->url()->setQueryString( array( 'tab' => 'node_filespurchased_filesPurchased' ) ), array( 'file_id IN(' . implode( ',', $files ) . ')' ), NULL, NULL, 'read' );

			$table->honorPinned = 1;
			$table->noModerate 	= 0;

			$table->sortBy			= \IPS\Request::i()->sortby ?: 'file_name';
			$table->sortDirection 	= \IPS\Request::i()->sortDirection ?: 'asc';
			$table->limit 			= 10;

			$table->classes 	= array( 'ipsDataList_large' );
			$table->title 		= \IPS\Member::loggedIn()->language()->pluralize(  \IPS\Member::loggedIn()->language()->get('download_file_count'), array( $total ) );

			return $table;
		}

		return \IPS\Theme::i()->getTemplate( 'profile', 'filespurchased', 'front' )->noFilesPurchased();
	}
}